- android-96.png

    .. image:: ./afwf/icons/android-96.png

- archive-folder-96.png

    .. image:: ./afwf/icons/archive-folder-96.png

- bash-96.png

    .. image:: ./afwf/icons/bash-96.png

- bookmark-96.png

    .. image:: ./afwf/icons/bookmark-96.png

- box-96.png

    .. image:: ./afwf/icons/box-96.png

- calendar-96.png

    .. image:: ./afwf/icons/calendar-96.png

- chat-96.png

    .. image:: ./afwf/icons/chat-96.png

- check-96.png

    .. image:: ./afwf/icons/check-96.png

- close-96.png

    .. image:: ./afwf/icons/close-96.png

- code-96.png

    .. image:: ./afwf/icons/code-96.png

- console-96.png

    .. image:: ./afwf/icons/console-96.png

- debug-96.png

    .. image:: ./afwf/icons/debug-96.png

- desktop-96.png

    .. image:: ./afwf/icons/desktop-96.png

- dictionary-96.png

    .. image:: ./afwf/icons/dictionary-96.png

- download-96.png

    .. image:: ./afwf/icons/download-96.png

- error-96.png

    .. image:: ./afwf/icons/error-96.png

- explosion-96.png

    .. image:: ./afwf/icons/explosion-96.png

- file-96.png

    .. image:: ./afwf/icons/file-96.png

- fire-96.png

    .. image:: ./afwf/icons/fire-96.png

- flask-96.png

    .. image:: ./afwf/icons/flask-96.png

- folder-96.png

    .. image:: ./afwf/icons/folder-96.png

- gear-96.png

    .. image:: ./afwf/icons/gear-96.png

- git-96.png

    .. image:: ./afwf/icons/git-96.png

- groupchat-96.png

    .. image:: ./afwf/icons/groupchat-96.png

- id-card-96.png

    .. image:: ./afwf/icons/id-card-96.png

- idea-96.png

    .. image:: ./afwf/icons/idea-96.png

- info-96.png

    .. image:: ./afwf/icons/info-96.png

- internet-96.png

    .. image:: ./afwf/icons/internet-96.png

- iphone-96.png

    .. image:: ./afwf/icons/iphone-96.png

- landline-96.png

    .. image:: ./afwf/icons/landline-96.png

- laptop-96.png

    .. image:: ./afwf/icons/laptop-96.png

- mail-96.png

    .. image:: ./afwf/icons/mail-96.png

- meeting-96.png

    .. image:: ./afwf/icons/meeting-96.png

- message-96.png

    .. image:: ./afwf/icons/message-96.png

- microsoft-excel-96.png

    .. image:: ./afwf/icons/microsoft-excel-96.png

- microsoft-powerpoint-96.png

    .. image:: ./afwf/icons/microsoft-powerpoint-96.png

- microsoft-word-96.png

    .. image:: ./afwf/icons/microsoft-word-96.png

- minus-96.png

    .. image:: ./afwf/icons/minus-96.png

- password-96.png

    .. image:: ./afwf/icons/password-96.png

- pause-96.png

    .. image:: ./afwf/icons/pause-96.png

- plus-96.png

    .. image:: ./afwf/icons/plus-96.png

- question-96.png

    .. image:: ./afwf/icons/question-96.png

- redo-96.png

    .. image:: ./afwf/icons/redo-96.png

- refresh-96.png

    .. image:: ./afwf/icons/refresh-96.png

- remove-96.png

    .. image:: ./afwf/icons/remove-96.png

- reset-96.png

    .. image:: ./afwf/icons/reset-96.png

- rocket-96.png

    .. image:: ./afwf/icons/rocket-96.png

- search-96.png

    .. image:: ./afwf/icons/search-96.png

- star-96.png

    .. image:: ./afwf/icons/star-96.png

- start-96.png

    .. image:: ./afwf/icons/start-96.png

- stop-96.png

    .. image:: ./afwf/icons/stop-96.png

- task-96.png

    .. image:: ./afwf/icons/task-96.png

- todo-96.png

    .. image:: ./afwf/icons/todo-96.png

- trash-96.png

    .. image:: ./afwf/icons/trash-96.png

- undo-96.png

    .. image:: ./afwf/icons/undo-96.png

- upload-96.png

    .. image:: ./afwf/icons/upload-96.png


